EXPORTS
	?GetPubSubData@LtkUtils@@YAPBUSKeyPair@1@AAH@Z @ 1 NONAME ABSENT ; struct LtkUtils::SKeyPair const * LtkUtils::GetPubSubData(int &)
	?HexDumpL@LtkUtils@@YAPAVHBufC16@@ABVTDesC8@@@Z @ 2 NONAME ; class HBufC16 * LtkUtils::HexDumpL(class TDesC8 const &)
	?HexDumpToOutput@LtkUtils@@YAXABVTDesC8@@AAVRIoWriteHandle@@@Z @ 3 NONAME ; void LtkUtils::HexDumpToOutput(class TDesC8 const &, class RIoWriteHandle &)
	?HexDumpToOutput@LtkUtils@@YAXABVTDesC8@@AAVRIoWriteHandle@@AAH@Z @ 4 NONAME ; void LtkUtils::HexDumpToOutput(class TDesC8 const &, class RIoWriteHandle &, int &)
	?HexDumpToRDebug@LtkUtils@@YAXABVTDesC8@@@Z @ 5 NONAME ; void LtkUtils::HexDumpToRDebug(class TDesC8 const &)
	?HexDumpToRDebug@LtkUtils@@YAXABVTDesC8@@AAH@Z @ 6 NONAME ; void LtkUtils::HexDumpToRDebug(class TDesC8 const &, int &)
	?InjectRawKeyEvent@LtkUtils@@YAHHHH@Z @ 7 NONAME ; int LtkUtils::InjectRawKeyEvent(int, int, int)
	?MakeHeapCellInvisible@LtkUtils@@YAXPAX@Z @ 8 NONAME ; void LtkUtils::MakeHeapCellInvisible(void *)
	?GetFriendlyThreadName@LtkUtils@@YAXVRThread@@AAV?$TBuf@$0BAA@@@@Z @ 9 NONAME ; void LtkUtils::GetFriendlyThreadName(class RThread, class TBuf<256> &)
	?MakeThreadNameFriendly@LtkUtils@@YAXAAV?$TBuf@$0BAA@@@@Z @ 10 NONAME ; void LtkUtils::MakeThreadNameFriendly(class TBuf<256> &)
	?RawPrint@LtkUtils@@YAXABVTDesC8@@@Z @ 11 NONAME ; void LtkUtils::RawPrint(class TDesC8 const &)
	?GetFriendlyProcessName@LtkUtils@@YAXABVRProcess@@AAVTDes16@@@Z @ 12 NONAME ; void LtkUtils::GetFriendlyProcessName(class RProcess const &, class TDes16 &)
	?MakeProcessNameFriendly@LtkUtils@@YAXAAVTDes16@@@Z @ 13 NONAME ; void LtkUtils::MakeProcessNameFriendly(class TDes16 &)
	?HexLexL@LtkUtils@@YAIAAVTLex16@@@Z @ 14 NONAME ; unsigned int LtkUtils::HexLexL(class TLex16 &)
	?ReplaceText@LtkUtils@@YAHAAVTDes16@@ABVTDesC16@@1@Z @ 15 NONAME ; int LtkUtils::ReplaceText(class TDes16 &, class TDesC16 const &, class TDesC16 const &)
	??0TErrorContext@LtkUtils@@QAE@ABVTDesC16@@@Z @ 16 NONAME ; LtkUtils::TErrorContext::TErrorContext(class TDesC16 const &)
	??0TErrorContext@LtkUtils@@QAE@XZ @ 17 NONAME ; LtkUtils::TErrorContext::TErrorContext(void)
	??1CIniFile@LtkUtils@@UAE@XZ @ 18 NONAME ; LtkUtils::CIniFile::~CIniFile(void)
	??1CIniReader@LtkUtils@@UAE@XZ @ 19 NONAME ; LtkUtils::CIniReader::~CIniReader(void)
	??1CSetting@LtkUtils@@UAE@XZ @ 20 NONAME ; LtkUtils::CSetting::~CSetting(void)
	??1CValue@LtkUtils@@UAE@XZ @ 21 NONAME ; LtkUtils::CValue::~CValue(void)
	?AsBool@CSetting@LtkUtils@@QBEHXZ @ 22 NONAME ; int LtkUtils::CSetting::AsBool(void) const
	?AsBool@CSetting@LtkUtils@@UBEHAAH@Z @ 23 NONAME ; int LtkUtils::CSetting::AsBool(int &) const
	?AsBool@CValue@LtkUtils@@UBEHAAH@Z @ 24 NONAME ; int LtkUtils::CValue::AsBool(int &) const
	?AsBoolL@CValue@LtkUtils@@QBEHXZ @ 25 NONAME ; int LtkUtils::CValue::AsBoolL(void) const
	?AsInt@CSetting@LtkUtils@@QBEHXZ @ 26 NONAME ; int LtkUtils::CSetting::AsInt(void) const
	?AsInt@CSetting@LtkUtils@@UBEHAAH@Z @ 27 NONAME ; int LtkUtils::CSetting::AsInt(int &) const
	?AsInt@CValue@LtkUtils@@UBEHAAH@Z @ 28 NONAME ; int LtkUtils::CValue::AsInt(int &) const
	?AsIntL@CValue@LtkUtils@@QBEHXZ @ 29 NONAME ; int LtkUtils::CValue::AsIntL(void) const
	?GetBool@CIniFile@LtkUtils@@QAEHABVTDesC16@@@Z @ 30 NONAME ; int LtkUtils::CIniFile::GetBool(class TDesC16 const &)
	?GetIdsL@CIniReader@LtkUtils@@QBEXAAV?$RArray@$$CBVTPtrC16@@@@@Z @ 31 NONAME ; void LtkUtils::CIniReader::GetIdsL(class RArray<class TPtrC16 const > &) const
	?GetInt@CIniFile@LtkUtils@@QAEHABVTDesC16@@@Z @ 32 NONAME ; int LtkUtils::CIniFile::GetInt(class TDesC16 const &)
	?GetSetting@CIniFile@LtkUtils@@QAEPAVCSetting@2@ABVTDesC16@@@Z @ 33 NONAME ; class LtkUtils::CSetting * LtkUtils::CIniFile::GetSetting(class TDesC16 const &)
	?GetString@CIniFile@LtkUtils@@QAEABVTDesC16@@ABV3@@Z @ 34 NONAME ; class TDesC16 const & LtkUtils::CIniFile::GetString(class TDesC16 const &)
	?GetValue@CIniReader@LtkUtils@@QBEPBVTDesC16@@ABV3@@Z @ 35 NONAME ; class TDesC16 const * LtkUtils::CIniReader::GetValue(class TDesC16 const &) const
	?GetValuesL@CIniReader@LtkUtils@@QAEXAAV?$RPointerArray@VCValue@LtkUtils@@@@@Z @ 36 NONAME ; void LtkUtils::CIniReader::GetValuesL(class RPointerArray<class LtkUtils::CValue> &)
	?GetValuesL@CIniReader@LtkUtils@@QBEXAAV?$RPointerArray@$$CBVCValue@LtkUtils@@@@@Z @ 37 NONAME ; void LtkUtils::CIniReader::GetValuesL(class RPointerArray<class LtkUtils::CValue const > &) const
	?Id@CValue@LtkUtils@@QBEABVTDesC16@@XZ @ 38 NONAME ; class TDesC16 const & LtkUtils::CValue::Id(void) const
	?IsSet@CSetting@LtkUtils@@QBEHXZ @ 39 NONAME ; int LtkUtils::CSetting::IsSet(void) const
	?LineNumber@CValue@LtkUtils@@QBEHXZ @ 40 NONAME ; int LtkUtils::CValue::LineNumber(void) const
	?LineNumber@TErrorContext@LtkUtils@@QAEHXZ @ 41 NONAME ; int LtkUtils::TErrorContext::LineNumber(void)
	?NewL@CIniFile@LtkUtils@@SAPAV12@ABVTDesC16@@0@Z @ 42 NONAME ; class LtkUtils::CIniFile * LtkUtils::CIniFile::NewL(class TDesC16 const &, class TDesC16 const &)
	?NewL@CIniReader@LtkUtils@@SAPAV12@ABVTDesC16@@VTErrorContext@2@@Z @ 43 NONAME ; class LtkUtils::CIniReader * LtkUtils::CIniReader::NewL(class TDesC16 const &, class LtkUtils::TErrorContext)
	?NewL@CSetting@LtkUtils@@SAPAV12@W4TSettingType@2@ABVTDesC16@@1111VTErrorContext@2@@Z @ 44 NONAME ; class LtkUtils::CSetting * LtkUtils::CSetting::NewL(enum LtkUtils::TSettingType, class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, class LtkUtils::TErrorContext)
	?NewL@CValue@LtkUtils@@SAPAV12@ABVTDesC16@@0VTErrorContext@2@@Z @ 45 NONAME ; class LtkUtils::CValue * LtkUtils::CValue::NewL(class TDesC16 const &, class TDesC16 const &, class LtkUtils::TErrorContext)
	?NewLC@CSetting@LtkUtils@@SAPAV12@W4TSettingType@2@ABVTDesC16@@1111VTErrorContext@2@@Z @ 46 NONAME ; class LtkUtils::CSetting * LtkUtils::CSetting::NewLC(enum LtkUtils::TSettingType, class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, class LtkUtils::TErrorContext)
	?NewLC@CValue@LtkUtils@@SAPAV12@ABVTDesC16@@0VTErrorContext@2@@Z @ 47 NONAME ; class LtkUtils::CValue * LtkUtils::CValue::NewLC(class TDesC16 const &, class TDesC16 const &, class LtkUtils::TErrorContext)
	?NextLine@TErrorContext@LtkUtils@@QAEXXZ @ 48 NONAME ; void LtkUtils::TErrorContext::NextLine(void)
	?ReadIniFileL@LtkUtils@@YAXAAVRIoReadHandle@@AAVMValueHandler@1@@Z @ 49 NONAME ; void LtkUtils::ReadIniFileL(class RIoReadHandle &, class LtkUtils::MValueHandler &)
	?ReadIniFileL@LtkUtils@@YAXABVTDesC16@@AAVMValueHandler@1@VTErrorContext@1@W4TFileNotFoundAction@1@@Z @ 50 NONAME ; void LtkUtils::ReadIniFileL(class TDesC16 const &, class LtkUtils::MValueHandler &, class LtkUtils::TErrorContext, enum LtkUtils::TFileNotFoundAction)
	?SetL@CIniFile@LtkUtils@@QAEXABVTDesC16@@0@Z @ 51 NONAME ; void LtkUtils::CIniFile::SetL(class TDesC16 const &, class TDesC16 const &)
	?SetL@CIniFile@LtkUtils@@QAEXABVTDesC16@@H@Z @ 52 NONAME ; void LtkUtils::CIniFile::SetL(class TDesC16 const &, int)
	?SetL@CSetting@LtkUtils@@QAEXH@Z @ 53 NONAME ; void LtkUtils::CSetting::SetL(int)
	?SetL@CSetting@LtkUtils@@UAEXABVTDesC16@@VTErrorContext@2@@Z @ 54 NONAME ; void LtkUtils::CSetting::SetL(class TDesC16 const &, class LtkUtils::TErrorContext)
	?SetL@CValue@LtkUtils@@UAEXABVTDesC16@@VTErrorContext@2@@Z @ 55 NONAME ; void LtkUtils::CValue::SetL(class TDesC16 const &, class LtkUtils::TErrorContext)
	?SetValueL@CIniReader@LtkUtils@@QAEXABVTDesC16@@0@Z @ 56 NONAME ; void LtkUtils::CIniReader::SetValueL(class TDesC16 const &, class TDesC16 const &)
	?StringLC@TErrorContext@LtkUtils@@QAEABVTDesC16@@XZ @ 57 NONAME ; class TDesC16 const & LtkUtils::TErrorContext::StringLC(void)
	?Value@CValue@LtkUtils@@QBEABVTDesC16@@XZ @ 58 NONAME ; class TDesC16 const & LtkUtils::CValue::Value(void) const
	?WriteIniFileL@LtkUtils@@YAXABVTDesC16@@AAVCIniReader@1@@Z @ 59 NONAME ; void LtkUtils::WriteIniFileL(class TDesC16 const &, class LtkUtils::CIniReader &)
	?WriteL@CIniFile@LtkUtils@@QAEXXZ @ 60 NONAME ; void LtkUtils::CIniFile::WriteL(void)
	?Description@CSetting@LtkUtils@@QAEABVTDesC16@@XZ @ 61 NONAME ; class TDesC16 const & LtkUtils::CSetting::Description(void)
	?Name@CSetting@LtkUtils@@QAEABVTDesC16@@XZ @ 62 NONAME ; class TDesC16 const & LtkUtils::CSetting::Name(void)
	?ClearL@CSetting@LtkUtils@@QAEXXZ @ 63 NONAME ; void LtkUtils::CSetting::ClearL(void)
	?RemoveValueL@CIniReader@LtkUtils@@QAEXABVTDesC16@@@Z @ 64 NONAME ; void LtkUtils::CIniReader::RemoveValueL(class TDesC16 const &)
	?MatchifyL@LtkUtils@@YAPAVHBufC16@@PAV2@@Z @ 65 NONAME ABSENT ; class HBufC16 * LtkUtils::MatchifyL(class HBufC16 *)
	??0RLtkBuf16@LtkUtils@@QAE@PAVHBufC16@@@Z @ 66 NONAME ; LtkUtils::RLtkBuf16::RLtkBuf16(class HBufC16 *)
	??0RLtkBuf16@LtkUtils@@QAE@XZ @ 67 NONAME ; LtkUtils::RLtkBuf16::RLtkBuf16(void)
	??0RLtkBuf8@LtkUtils@@QAE@PAVHBufC8@@@Z @ 68 NONAME ; LtkUtils::RLtkBuf8::RLtkBuf8(class HBufC8 *)
	??0RLtkBuf8@LtkUtils@@QAE@XZ @ 69 NONAME ; LtkUtils::RLtkBuf8::RLtkBuf8(void)
	?AppendFormatL@RLtkBuf16@LtkUtils@@QAAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 70 NONAME ; void LtkUtils::RLtkBuf16::AppendFormatL(class TRefByValue<class TDesC16 const >, ...)
	?AppendFormatL@RLtkBuf8@LtkUtils@@QAAXV?$TRefByValue@$$CBVTDesC8@@@@ZZ @ 71 NONAME ; void LtkUtils::RLtkBuf8::AppendFormatL(class TRefByValue<class TDesC8 const >, ...)
	?AppendL@RLtkBuf16@LtkUtils@@QAEXABVTDesC16@@@Z @ 72 NONAME ; void LtkUtils::RLtkBuf16::AppendL(class TDesC16 const &)
	?AppendL@RLtkBuf16@LtkUtils@@QAEXABVTDesC8@@@Z @ 73 NONAME ; void LtkUtils::RLtkBuf16::AppendL(class TDesC8 const &)
	?AppendL@RLtkBuf16@LtkUtils@@QAEXVTChar@@@Z @ 74 NONAME ; void LtkUtils::RLtkBuf16::AppendL(class TChar)
	?AppendL@RLtkBuf8@LtkUtils@@QAEXABVTDesC16@@@Z @ 75 NONAME ; void LtkUtils::RLtkBuf8::AppendL(class TDesC16 const &)
	?AppendL@RLtkBuf8@LtkUtils@@QAEXABVTDesC8@@@Z @ 76 NONAME ; void LtkUtils::RLtkBuf8::AppendL(class TDesC8 const &)
	?AppendL@RLtkBuf8@LtkUtils@@QAEXVTChar@@@Z @ 77 NONAME ; void LtkUtils::RLtkBuf8::AppendL(class TChar)
	?Assign@RLtkBuf16@LtkUtils@@QAEXPAVHBufC16@@@Z @ 78 NONAME ; void LtkUtils::RLtkBuf16::Assign(class HBufC16 *)
	?Assign@RLtkBuf8@LtkUtils@@QAEXPAVHBufC8@@@Z @ 79 NONAME ; void LtkUtils::RLtkBuf8::Assign(class HBufC8 *)
	?Close@RLtkBuf16@LtkUtils@@QAEXXZ @ 80 NONAME ; void LtkUtils::RLtkBuf16::Close(void)
	?Close@RLtkBuf8@LtkUtils@@QAEXXZ @ 81 NONAME ; void LtkUtils::RLtkBuf8::Close(void)
	?Create@RLtkBuf16@LtkUtils@@QAEHH@Z @ 82 NONAME ; int LtkUtils::RLtkBuf16::Create(int)
	?Create@RLtkBuf8@LtkUtils@@QAEHH@Z @ 83 NONAME ; int LtkUtils::RLtkBuf8::Create(int)
	?CreateL@RLtkBuf16@LtkUtils@@QAEXH@Z @ 84 NONAME ; void LtkUtils::RLtkBuf16::CreateL(int)
	?CreateL@RLtkBuf8@LtkUtils@@QAEXH@Z @ 85 NONAME ; void LtkUtils::RLtkBuf8::CreateL(int)
	?CreateLC@RLtkBuf16@LtkUtils@@QAEXH@Z @ 86 NONAME ; void LtkUtils::RLtkBuf16::CreateLC(int)
	?CreateLC@RLtkBuf8@LtkUtils@@QAEXH@Z @ 87 NONAME ; void LtkUtils::RLtkBuf8::CreateLC(int)
	?CreateMax@RLtkBuf16@LtkUtils@@QAEHH@Z @ 88 NONAME ; int LtkUtils::RLtkBuf16::CreateMax(int)
	?CreateMax@RLtkBuf8@LtkUtils@@QAEHH@Z @ 89 NONAME ; int LtkUtils::RLtkBuf8::CreateMax(int)
	?CreateMaxL@RLtkBuf16@LtkUtils@@QAEXH@Z @ 90 NONAME ; void LtkUtils::RLtkBuf16::CreateMaxL(int)
	?CreateMaxL@RLtkBuf8@LtkUtils@@QAEXH@Z @ 91 NONAME ; void LtkUtils::RLtkBuf8::CreateMaxL(int)
	?HasPrefix@LtkUtils@@YAHABVTDesC16@@0@Z @ 92 NONAME ; int LtkUtils::HasPrefix(class TDesC16 const &, class TDesC16 const &)
	?HasPrefix@LtkUtils@@YAHABVTDesC8@@0@Z @ 93 NONAME ; int LtkUtils::HasPrefix(class TDesC8 const &, class TDesC8 const &)
	?HexLex@LtkUtils@@YAHAAVTLex16@@AAI@Z @ 94 NONAME ; int LtkUtils::HexLex(class TLex16 &, unsigned int &)
	?HexLex@LtkUtils@@YAHAAVTLex8@@AAI@Z @ 95 NONAME ; int LtkUtils::HexLex(class TLex8 &, unsigned int &)
	?HexLexL@LtkUtils@@YAIAAVTLex8@@@Z @ 96 NONAME ; unsigned int LtkUtils::HexLexL(class TLex8 &)
	?ReAlloc@RLtkBuf16@LtkUtils@@QAEHH@Z @ 97 NONAME ; int LtkUtils::RLtkBuf16::ReAlloc(int)
	?ReAlloc@RLtkBuf8@LtkUtils@@QAEHH@Z @ 98 NONAME ; int LtkUtils::RLtkBuf8::ReAlloc(int)
	?ReAllocL@RLtkBuf16@LtkUtils@@QAEXH@Z @ 99 NONAME ; void LtkUtils::RLtkBuf16::ReAllocL(int)
	?ReAllocL@RLtkBuf8@LtkUtils@@QAEXH@Z @ 100 NONAME ; void LtkUtils::RLtkBuf8::ReAllocL(int)
	?ReplaceAllL@RLtkBuf16@LtkUtils@@QAEXABVTDesC16@@0@Z @ 101 NONAME ; void LtkUtils::RLtkBuf16::ReplaceAllL(class TDesC16 const &, class TDesC16 const &)
	?ReplaceAllL@RLtkBuf8@LtkUtils@@QAEXABVTDesC8@@0@Z @ 102 NONAME ; void LtkUtils::RLtkBuf8::ReplaceAllL(class TDesC8 const &, class TDesC8 const &)
	?ReplaceL@RLtkBuf16@LtkUtils@@QAEXHHABVTDesC16@@@Z @ 103 NONAME ; void LtkUtils::RLtkBuf16::ReplaceL(int, int, class TDesC16 const &)
	?ReplaceL@RLtkBuf8@LtkUtils@@QAEXHHABVTDesC8@@@Z @ 104 NONAME ; void LtkUtils::RLtkBuf8::ReplaceL(int, int, class TDesC8 const &)
	?ReserveExtra@RLtkBuf16@LtkUtils@@QAEHH@Z @ 105 NONAME ; int LtkUtils::RLtkBuf16::ReserveExtra(int)
	?ReserveExtra@RLtkBuf8@LtkUtils@@QAEHH@Z @ 106 NONAME ; int LtkUtils::RLtkBuf8::ReserveExtra(int)
	?ReserveExtraL@RLtkBuf16@LtkUtils@@QAEXH@Z @ 107 NONAME ; void LtkUtils::RLtkBuf16::ReserveExtraL(int)
	?ReserveExtraL@RLtkBuf8@LtkUtils@@QAEXH@Z @ 108 NONAME ; void LtkUtils::RLtkBuf8::ReserveExtraL(int)
	?ToHBuf@RLtkBuf16@LtkUtils@@QAEPAVHBufC16@@XZ @ 109 NONAME ; class HBufC16 * LtkUtils::RLtkBuf16::ToHBuf(void)
	?ToHBuf@RLtkBuf8@LtkUtils@@QAEPAVHBufC8@@XZ @ 110 NONAME ; class HBufC8 * LtkUtils::RLtkBuf8::ToHBuf(void)
	??1CHalAttribute@LtkUtils@@UAE@XZ @ 111 NONAME ; LtkUtils::CHalAttribute::~CHalAttribute(void)
	?GetHalInfoL@LtkUtils@@YAXAAV?$RPointerArray@VCHalAttribute@LtkUtils@@@@@Z @ 112 NONAME ; void LtkUtils::GetHalInfoL(class RPointerArray<class LtkUtils::CHalAttribute> &)
	?GetHalInfoL@LtkUtils@@YAPAVCHalAttribute@1@HH@Z @ 113 NONAME ; class LtkUtils::CHalAttribute * LtkUtils::GetHalInfoL(int, int)
	?GetHalInfoL@LtkUtils@@YAPAVCHalAttribute@1@H@Z @ 114 NONAME ; class LtkUtils::CHalAttribute * LtkUtils::GetHalInfoL(int)
	?GetHalInfoForValueL@LtkUtils@@YAPAVCHalAttribute@1@HHH@Z @ 115 NONAME ; class LtkUtils::CHalAttribute * LtkUtils::GetHalInfoForValueL(int, int, int)
	?GetHBuf@RLtkBuf8@LtkUtils@@QBEPAVHBufC8@@XZ @ 116 NONAME ; class HBufC8 * LtkUtils::RLtkBuf8::GetHBuf(void) const
	?GetHBuf@RLtkBuf16@LtkUtils@@QBEPAVHBufC16@@XZ @ 117 NONAME ; class HBufC16 * LtkUtils::RLtkBuf16::GetHBuf(void) const
	?CopyAsUtf8L@RLtkBuf8@LtkUtils@@QAEXABVTDesC16@@@Z @ 118 NONAME ; void LtkUtils::RLtkBuf8::CopyAsUtf8L(class TDesC16 const &)
	?Utf8L@LtkUtils@@YAPAVHBufC8@@ABVTDesC16@@@Z @ 119 NONAME ; class HBufC8 * LtkUtils::Utf8L(class TDesC16 const &)
	?AppendUtf8L@RLtkBuf16@LtkUtils@@QAEXABVTDesC8@@AAH@Z @ 120 NONAME ; void LtkUtils::RLtkBuf16::AppendUtf8L(class TDesC8 const &, int &)
	?AppendUtf8L@RLtkBuf16@LtkUtils@@QAEXABVTDesC8@@@Z @ 121 NONAME ; void LtkUtils::RLtkBuf16::AppendUtf8L(class TDesC8 const &)
	?DecodeUtf8L@LtkUtils@@YAPAVHBufC16@@ABVTDesC8@@@Z @ 122 NONAME ; class HBufC16 * LtkUtils::DecodeUtf8L(class TDesC8 const &)
	?CopyFromUtf8L@RLtkBuf16@LtkUtils@@QAEXABVTDesC8@@@Z @ 123 NONAME ; void LtkUtils::RLtkBuf16::CopyFromUtf8L(class TDesC8 const &)
	?FinalizeUtf8@RLtkBuf16@LtkUtils@@QAEXAAH@Z @ 124 NONAME ; void LtkUtils::RLtkBuf16::FinalizeUtf8(int &)
	?FinalizeUtf8@RLtkBuf16@LtkUtils@@QAEHXZ @ 125 NONAME ; int LtkUtils::RLtkBuf16::FinalizeUtf8(void)
	??0RAllocatorHelper@LtkUtils@@QAE@XZ @ 126 NONAME ; LtkUtils::RAllocatorHelper::RAllocatorHelper(void)
	?Open@RProxyAllocatorHelper@LtkUtils@@QAEHAAVRMemoryAccess@@I@Z @ 127 NONAME ; int LtkUtils::RProxyAllocatorHelper::Open(class RMemoryAccess &, unsigned int)
	?Open@RAllocatorHelper@LtkUtils@@QAEHPAVRAllocator@@@Z @ 128 NONAME ; int LtkUtils::RAllocatorHelper::Open(class RAllocator *)
	??0RProxyAllocatorHelper@LtkUtils@@QAE@XZ @ 129 NONAME ; LtkUtils::RProxyAllocatorHelper::RProxyAllocatorHelper(void)
	?Close@RAllocatorHelper@LtkUtils@@UAEXXZ @ 130 NONAME ; void LtkUtils::RAllocatorHelper::Close(void)
	?SetCellNestingLevel@RAllocatorHelper@LtkUtils@@QAEHPAXH@Z @ 131 NONAME ; int LtkUtils::RAllocatorHelper::SetCellNestingLevel(void *, int)
	?AllocationCount@RAllocatorHelper@LtkUtils@@QAEHXZ @ 132 NONAME ; int LtkUtils::RAllocatorHelper::AllocationCount(void)
	?CommittedSize@RAllocatorHelper@LtkUtils@@QAEHXZ @ 133 NONAME ; int LtkUtils::RAllocatorHelper::CommittedSize(void)
	?RefreshDetails@RAllocatorHelper@LtkUtils@@QAEHXZ @ 134 NONAME ; int LtkUtils::RAllocatorHelper::RefreshDetails(void)
	?AllocatedSize@RAllocatorHelper@LtkUtils@@QAEHXZ @ 135 NONAME ; int LtkUtils::RAllocatorHelper::AllocatedSize(void)
	?OpenChunkHeap@RProxyAllocatorHelper@LtkUtils@@QAEHAAVRMemoryAccess@@PAX@Z @ 136 NONAME ; int LtkUtils::RProxyAllocatorHelper::OpenChunkHeap(class RMemoryAccess &, void *)
	?MaxCommittedSize@RAllocatorHelper@LtkUtils@@QAEHXZ @ 137 NONAME ; int LtkUtils::RAllocatorHelper::MaxCommittedSize(void)
	?AllocCountForCell@RAllocatorHelper@LtkUtils@@QBEHPAX@Z @ 138 NONAME ; int LtkUtils::RAllocatorHelper::AllocCountForCell(void *) const
	?CommittedFreeSpace@RAllocatorHelper@LtkUtils@@QAEHXZ @ 139 NONAME ; int LtkUtils::RAllocatorHelper::CommittedFreeSpace(void)
	?CountUnusedPages@RAllocatorHelper@LtkUtils@@QAEHXZ @ 140 NONAME ; int LtkUtils::RAllocatorHelper::CountUnusedPages(void)
	?Walk@RAllocatorHelper@LtkUtils@@QAEHP6AHPAXW4TCellType@12@KH@Z0@Z @ 141 NONAME ; int LtkUtils::RAllocatorHelper::Walk(int (*)(void *, enum LtkUtils::RAllocatorHelper::TCellType, unsigned long, int), void *)
	?MinCommittedSize@RAllocatorHelper@LtkUtils@@QAEHXZ @ 142 NONAME ; int LtkUtils::RAllocatorHelper::MinCommittedSize(void)
	?AllocatorAddress@RAllocatorHelper@LtkUtils@@QBEKXZ @ 143 NONAME ; unsigned long LtkUtils::RAllocatorHelper::AllocatorAddress(void) const
	?GetCellNestingLevel@RAllocatorHelper@LtkUtils@@QAEHPAXAAH@Z @ 144 NONAME ; int LtkUtils::RAllocatorHelper::GetCellNestingLevel(void *, int &)
	?Walk@RAllocatorHelper@LtkUtils@@QAEHP6AHAAV12@PAXW4TCellType@12@KH@Z1@Z @ 145 NONAME ; int LtkUtils::RAllocatorHelper::Walk(int (*)(class LtkUtils::RAllocatorHelper &, void *, enum LtkUtils::RAllocatorHelper::TCellType, unsigned long, int), void *)
	?Walk@RAllocatorHelper@LtkUtils@@QAEHP6AHAAV12@PAXW4TExtendedCellType@12@KH@Z1@Z @ 146 NONAME ; int LtkUtils::RAllocatorHelper::Walk(int (*)(class LtkUtils::RAllocatorHelper &, void *, enum LtkUtils::RAllocatorHelper::TExtendedCellType, unsigned long, int), void *)
	?SizeForCellType@RAllocatorHelper@LtkUtils@@QAEHW4TExtendedCellType@12@@Z @ 147 NONAME ; int LtkUtils::RAllocatorHelper::SizeForCellType(enum LtkUtils::RAllocatorHelper::TExtendedCellType)
	?CountForCellType@RAllocatorHelper@LtkUtils@@QAEHW4TExtendedCellType@12@@Z @ 148 NONAME ; int LtkUtils::RAllocatorHelper::CountForCellType(enum LtkUtils::RAllocatorHelper::TExtendedCellType)
	?Close@RProxyAllocatorHelper@LtkUtils@@UAEXXZ @ 149 NONAME ; void LtkUtils::RProxyAllocatorHelper::Close(void)
	?AllocatorIsUdeb@RAllocatorHelper@LtkUtils@@QBEHXZ @ 150 NONAME ; int LtkUtils::RAllocatorHelper::AllocatorIsUdeb(void) const
	?FormatSize@LtkUtils@@YAXAAVTDes8@@_J@Z @ 151 NONAME ; void LtkUtils::FormatSize(class TDes8 &, long long)
	?FormatSize@LtkUtils@@YAXAAVTDes16@@_J@Z @ 152 NONAME ; void LtkUtils::FormatSize(class TDes16 &, long long)
	?Description@RAllocatorHelper@LtkUtils@@QBEABVTDesC16@@XZ @ 153 NONAME ; class TDesC16 const & LtkUtils::RAllocatorHelper::Description(void) const
	?GetSystemDrive@LtkUtils@@YADXZ @ 154 NONAME ; char LtkUtils::GetSystemDrive(void)

